==> ask-sdk-model-1.24.0.tar.gz: ask-sdk-model-1.24.0/ask_sdk_model/services/reminder_management/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .reminder_deleted_event_request import ReminderDeletedEventRequest
from .reminder import Reminder
from .reminder_started_event_request import ReminderStartedEventRequest
from .error import Error
from .get_reminder_response import GetReminderResponse
from .alert_info import AlertInfo
from .trigger import Trigger
from .reminder_response import ReminderResponse
from .get_reminders_response import GetRemindersResponse
from .reminder_updated_event_request import ReminderUpdatedEventRequest
from .reminder_status_changed_event_request import ReminderStatusChangedEventRequest
from .recurrence_freq import RecurrenceFreq
from .spoken_text import SpokenText
from .alert_info_spoken_info import SpokenInfo
from .status import Status
from .recurrence import Recurrence
from .recurrence_day import RecurrenceDay
from .reminder_deleted_event import ReminderDeletedEvent
from .push_notification_status import PushNotificationStatus
from .trigger_type import TriggerType
from .reminder_created_event_request import ReminderCreatedEventRequest
from .reminder_request import ReminderRequest
from .event import Event
from .push_notification import PushNotification
from .reminder_management_service_client import ReminderManagementServiceClient

==> ask-sdk-model-1.32.0.tar.gz: ask-sdk-model-1.32.0/ask_sdk_model/services/reminder_management/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .reminder_management_service_client import ReminderManagementServiceClient
from .reminder_updated_event_request import ReminderUpdatedEventRequest
from .recurrence_day import RecurrenceDay
from .event import Event
from .reminder_status_changed_event_request import ReminderStatusChangedEventRequest
from .error import Error
from .get_reminders_response import GetRemindersResponse
from .reminder_deleted_event_request import ReminderDeletedEventRequest
from .reminder_started_event_request import ReminderStartedEventRequest
from .reminder_request import ReminderRequest
from .recurrence import Recurrence
from .reminder_deleted_event import ReminderDeletedEvent
from .spoken_text import SpokenText
from .alert_info import AlertInfo
from .reminder_created_event_request import ReminderCreatedEventRequest
from .reminder_response import ReminderResponse
from .push_notification_status import PushNotificationStatus
from .trigger_type import TriggerType
from .push_notification import PushNotification
from .alert_info_spoken_info import AlertInfoSpokenInfo
from .get_reminder_response import GetReminderResponse
from .recurrence_freq import RecurrenceFreq
from .status import Status
from .trigger import Trigger
from .reminder import Reminder
